<?php
/*
Plugin Name: YARD - Wordpress Plugin
Description: Displays a Yard calendar in your WordPress installation. Click "Manage your calendar" for the documentation.
Version: v1.10
Author: <a href="https://www.yard.global/products/calendar/publish/" target="_blank">Team YARD</a> | <a href="https://www.yard.global/my-yard/calendar-manager/" target="_blank">Manage your calendar</a>
Author URI: https://www.yard.global
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

$plugin_version = "1.10";

// Set up environment-based configurations
if ($_SERVER['HTTP_HOST'] == "www-dev.yard.global") {
    $plugin_settings['environment'] = "dev";
} elseif ($_SERVER['HTTP_HOST'] == "localhost:2042") {
    $plugin_settings['environment'] = "local";
} else {
    $plugin_settings['environment'] = "live";
}

// $plugin_settings['environment'] = "dev";

if ($plugin_settings['environment'] == "dev") {
    $plugin_settings['hostname'] = "https://www-dev.yard.global";
} elseif ($plugin_settings['environment'] == "local") {
    $plugin_settings['hostname'] = "http://localhost:2042";
} else {
    $plugin_settings['hostname'] = "https://www.yard.global";
}

// Set default options upon plugin activation
function yard_plugin_activate() {
    if (get_option('yard_plugin_active') === false) {
        update_option('yard_plugin_active', 'yes');
    }
}
register_activation_hook(__FILE__, 'yard_plugin_activate');

// Add a menu item for the plugin settings page
function yard_plugin_settings_menu() {
    add_menu_page(
        'Yard Plugin Settings',
        'Yard Plugin',
        'manage_options',
        'yard-plugin-settings',
        'yard_plugin_settings_page',
        'dashicons-admin-generic',
        100
    );
}
add_action('admin_menu', 'yard_plugin_settings_menu');

// Display the settings page
function yard_plugin_settings_page() {
    global $plugin_version;

    // Check if the user has permissions
    if (!current_user_can('manage_options')) {
        return;
    }

    // Handle form submission
    if (isset($_POST['yard_plugin_save_settings'])) {
        check_admin_referer('yard_plugin_settings_nonce', 'yard_plugin_nonce');

        // Save settings to the database
        $is_active = isset($_POST['yard_plugin_active']) ? 'yes' : 'no';
        #$act_code = sanitize_text_field($_POST['yard_plugin_act_code']);

        update_option('yard_plugin_active', $is_active);
        #update_option('yard_plugin_act_code', $act_code);

        echo '<div class="updated"><p>Settings saved successfully.</p></div>';
    }

    // Retrieve current settings
    $is_active = get_option('yard_plugin_active', 'no');
    #$act_code = get_option('yard_plugin_act_code', '');
    ?>

    <style>
        .yard-plugin-settings ul {
            list-style: disc;
            padding-left: 20px;
            margin-bottom: 20px;
            line-height: 1.1;
        }

        .yard-plugin-settings .form-table td {
            padding-top: 5px;
            padding-bottom: 5px;
        }

        .yard-plugin-settings .form-table th {
            padding-top: 8px;
            padding-bottom: 5px;
        }
    </style>
    <div class="yard-plugin-settings wrap">
        <h1>Yard Plugin Settings</h1>

        <form method="post" action="">
            <?php wp_nonce_field('yard_plugin_settings_nonce', 'yard_plugin_nonce'); ?>
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="yard_plugin_active">Enable Yard Calendar</label></th>
                    <td><input type="checkbox" name="yard_plugin_active" id="yard_plugin_active" value="yes" <?php checked($is_active, 'yes'); ?>></td>
                </tr>
                <!--tr>
                    <th scope="row"><label for="yard_plugin_act_code">Activation Code</label></th>
                    <td><input type="text" name="yard_plugin_act_code" id="yard_plugin_act_code" value="<?php echo esc_attr($act_code); ?>" class="regular-text"></td>
                </tr-->
            </table>
            <?php submit_button('Save Settings', 'primary', 'yard_plugin_save_settings'); ?>
        </form>

        <p><strong>You are using Yard Plugin v<?php echo esc_html($plugin_version); ?>. Visit the Yard website for details:</strong></p>
        <ul>
            <li><a href="https://www.yard.global/products/calendar/publish/wordpress-integration/" target="_blank">Plugin Documentation</a></li>
            <li><a href="https://www.yard.global/products/calendar/publish/wordpress-integration/changelog/" target="_blank">Plugin Changelog</a></li>
            <li><a href="https://www.yard.global/my-yard/calendar-wizard/" target="_blank">Manage your calendar</a></li>
        </ul>

        <p>Questions? Write to <a href="mailto:team@yard.global">team@yard.global</a></p>

    </div>
    <?php
}

// Add a "Settings" link on the Plugins page
function yard_plugin_settings_link($links) {
    $settings_link = '<a href="admin.php?page=yard-plugin-settings">Settings</a>';
    array_unshift($links, $settings_link); // Add the link at the beginning of the array
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'yard_plugin_settings_link');

// Check if the user is viewing a page
function is_user_viewing_page() {
    if (is_admin() || defined('REST_REQUEST') && REST_REQUEST) {
        return false;
    }

    if (is_page() && !is_preview()) {
        return true;
    }

    return false;
}


// Fetch and render the events
function yard_fetch_events($params) {
    global $plugin_settings;
    global $plugin_version;

    $is_active = get_option('yard_plugin_active', 'no');

    // Filter out empty values
    $filteredParams = array_filter($params, function ($value) {
        return $value !== '';
    });

    // Convert to URL parameters
    $urlParams = http_build_query($filteredParams).'&plugin='.$plugin_version;

    ob_start();
    ?>

    <?php if ($is_active === 'yes'):?>
        <script src="<?php echo esc_url($plugin_settings['hostname']); ?>/yard-iframe.js?<?php echo esc_attr($urlParams); ?>" class="yard-iframe" defer></script>
    <?php else:?>
        You have to activate the Yard Plugin on the <a href="/wp-admin/admin.php?page=yard-plugin-settings">settings page</a>.
    <?php endif;?>

    <?php
    return ob_get_clean();
}


// Register the shortcode
function yard_events_shortcode($atts) {

    if (!isset($atts['code'])) { $atts['code'] = ''; }
    if (!isset($atts['city'])) { $atts['city'] = ''; }
    if (!isset($atts['country'])) { $atts['country'] = ''; }
    if (!isset($atts['region'])) { $atts['region'] = ''; }
    if (!isset($atts['maxwidth'])) { $atts['maxwidth'] = ''; }
    if (!isset($atts['topic'])) { $atts['topic'] = ''; }
    if (!isset($atts['tags'])) { $atts['tags'] = ''; }
    if (!isset($atts['mode'])) { $atts['mode'] = ''; }
    if (!isset($atts['distribution'])) { $atts['distribution'] = ''; }
    if (!isset($atts['format'])) { $atts['format'] = ''; }
    if (!isset($atts['location'])) { $atts['location'] = ''; }
    if (!isset($atts['showdateas'])) { $atts['showdateas'] = ''; }
    if (!isset($atts['sortby'])) { $atts['sortby'] = ''; }
    if (!isset($atts['text'])) { $atts['text'] = ''; }

    if (!is_user_viewing_page()) {
        return '';
    }

    return yard_fetch_events($atts);
}
add_shortcode('yard_plugin', 'yard_events_shortcode');

// Enqueue plugin CSS
function yard_enqueue_styles() {
    wp_enqueue_style('yard-plugin-style', plugin_dir_url(__FILE__) . 'yard-plugin.css');
}
add_action('wp_enqueue_scripts', 'yard_enqueue_styles');
